==========================
Update source installation
==========================

This steps can be applied if you installed via the :ref:`source-installation`
method.

#. Update via mercurial in the checkout directory::

   $ hg pull -u

#. Run `buildout`::

   $ bin/buildout

#. :ref:`runtheapplication`
